@@ -10,11 +10,12 @@ from matterlab_pumps.base_pump import SyringePump
 
 class JKemPump(SyringePump, SerialDevice):
     category="Pump"
+    ui_fields  = ("com_port", "address", "syringe_volume", "home_pos")
     def __init__(self,
                  com_port: str,
                  address: Union[str, int],
-                 syringe_volume: float = 1e-2,
-                 num_valve_port: int = 8,
+                 syringe_volume: float,
+                 num_valve_port: int,
                  ports: Optional[Dict[str, int]] = None,
                  init_valve: int = 5,
                  out_valve: int = 5,
